@@ -53,7 +53,7 @@ class DiskReplicaPairAddition(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["DiskReplicaPairAdditionProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[DiskReplicaPairAdditionProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -166,7 +166,7 @@ class RosDiskReplicaPairAddition(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosDiskReplicaPairAdditionProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosDiskReplicaPairAdditionProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
